==> lightdash_client_python-0.1200.0-py3-none-any.whl: lightdash_client/models/pick_create_postgres_credentials_type_or_user_or_password.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.warehouse_types_postgres import WarehouseTypesPOSTGRES

T = TypeVar("T", bound="PickCreatePostgresCredentialsTypeOrUserOrPassword")


@_attrs_define
class PickCreatePostgresCredentialsTypeOrUserOrPassword:
    """From T, pick a set of properties whose keys are in the union K

    Attributes:
        type (WarehouseTypesPOSTGRES):
        user (str):
        password (str):
    """

    type: WarehouseTypesPOSTGRES
    user: str
    password: str
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        user = self.user

        password = self.password

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
                "user": user,
                "password": password,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = WarehouseTypesPOSTGRES(d.pop("type"))

        user = d.pop("user")

        password = d.pop("password")

        pick_create_postgres_credentials_type_or_user_or_password = cls(
            type=type,
            user=user,
            password=password,
        )

        pick_create_postgres_credentials_type_or_user_or_password.additional_properties = d
        return pick_create_postgres_credentials_type_or_user_or_password

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> lightdash_client_python-0.1471.0-py3-none-any.whl: lightdash_client/models/pick_create_postgres_credentials_type_or_user_or_password.py <==
from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.warehouse_types_postgres import WarehouseTypesPOSTGRES
from ..types import UNSET, Unset

T = TypeVar("T", bound="PickCreatePostgresCredentialsTypeOrUserOrPassword")


@_attrs_define
class PickCreatePostgresCredentialsTypeOrUserOrPassword:
    """From T, pick a set of properties whose keys are in the union K

    Attributes:
        user (str):
        type (WarehouseTypesPOSTGRES):
        password (str):
    """

    user: str
    type: WarehouseTypesPOSTGRES
    password: str
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        user = self.user

        type = self.type.value

        password = self.password

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "user": user,
                "type": type,
                "password": password,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        user = d.pop("user")

        type = WarehouseTypesPOSTGRES(d.pop("type"))

        password = d.pop("password")

        pick_create_postgres_credentials_type_or_user_or_password = cls(
            user=user,
            type=type,
            password=password,
        )

        pick_create_postgres_credentials_type_or_user_or_password.additional_properties = d
        return pick_create_postgres_credentials_type_or_user_or_password

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
